/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { SharedString } from "@fluidframework/sequence";
import React from "react";
export interface ICollaborativeTextAreaProps {
    /**
     * The SharedString that will store the text from the textarea.
     */
    sharedString: SharedString;
    /**
     * Whether spellCheck should be enabled.  Defaults to false.
     */
    spellCheck?: boolean;
    className?: string;
    style?: React.CSSProperties;
}
export interface ICollaborativeTextAreaState {
    selectionEnd: number;
    selectionStart: number;
    text: string;
}
/**
 * Given a SharedString will produce a collaborative textarea.
 */
export declare class CollaborativeTextArea extends React.Component<ICollaborativeTextAreaProps, ICollaborativeTextAreaState> {
    private readonly ref;
    constructor(props: ICollaborativeTextAreaProps);
    componentDidMount(): void;
    private setCaretPosition;
    render(): JSX.Element;
    private handleChange;
    /**
     * Update the current caret selection.
     * We need to do this before we do any handleChange action or we will have lost our
     * cursor position and not be able to accurately update the shared string.
     */
    private updateSelection;
}
//# sourceMappingURL=CollaborativeTextArea.d.ts.map